"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.validateFnr = validateFnr;
exports.validateOTP = validateOTP;
exports.sendPostFnr = sendPostFnr;
exports.saveDocumentToDB = saveDocumentToDB;
exports.updateTokenOnClose = updateTokenOnClose;

var request = _interopRequireWildcard(require("request-promise"));

var constants = _interopRequireWildcard(require("./constants"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

/**
 * Function to validate that a birth number is 11 digits.
 *
 * @param fnr Birth number
 * @returns {boolean}
 */
function validateFnr(fnr) {
  const fnrTrimmed = fnr.replace(/[^\d]/g, '');
  const regex = /^[0-3][0-9][0,1][0-9][0-9]{7}$/g;
  const valid = fnrTrimmed.match(regex);
  return valid !== null ? fnrTrimmed : null;
}
/**
 * Function to validate that the one-time password is 4 digits.
 *
 * @param otp One-time password
 * @returns {boolean}
 */


function validateOTP(otp) {
  const otpTrimmed = otp.replace(/[^\d]/g, '');
  const regex = /^[0-9]{4}$/g;
  const valid = otpTrimmed.match(regex);
  return valid !== null ? otpTrimmed : null;
}
/**
 * Sanitize template literal inputs by escaping characters into XML entities
 * to use in SSML
 * Also normalize the extra spacing for better text rendering in SSML
 * A tag function used by ES6 tagged template literals
 * Sends a POST request to the API to login to Norsk Tipping.
 *
 * @param {string} fnr Birth number
 * @param {request.CookieJar} cookieJar For saving the cookies
 * @returns {Promise}
 */


function sendPostFnr(fnr, cookieJar) {
  const options = {
    headers: {
      'content-type': 'application/json'
    },
    url: constants.API_URLS.LOGIN,
    body: `{ "personId": "${fnr}"}`,
    jar: cookieJar,
    resolveWithFullResponse: true
  };
  return request.post(options);
}
/**
 * Updates an already existing document in the database.
 *
 * @param {FirebaseFirestore.Firestore} db Reference to the database
 * @param {DialogflowConversation} conv Reference to the document
 * @param {Object} data Data to update in the document
 */


function saveDocumentToDB(_x, _x2, _x3) {
  return _saveDocumentToDB.apply(this, arguments);
}
/**
 * Update the token in the database when the user closes the conversation.
 *
 * @param {FirebaseFirestore.Firestore} db Reference to the database
 * @param {DialogflowConversation} conv Reference to the document
 * @param {request.CookieJar} cookieJar Cookie jar
 */


function _saveDocumentToDB() {
  _saveDocumentToDB = _asyncToGenerator(function* (db, conv, data) {
    try {
      yield db.collection('users').doc(conv.user.storage.db).update(data);
      console.log('Saved document to database:', conv.user.storage.db);
    } catch (error) {
      return console.error('Error saving document to database:', error);
    }
  });
  return _saveDocumentToDB.apply(this, arguments);
}

function updateTokenOnClose(_x4, _x5, _x6) {
  return _updateTokenOnClose.apply(this, arguments);
}

function _updateTokenOnClose() {
  _updateTokenOnClose = _asyncToGenerator(function* (db, conv, cookieJar) {
    const parsedCookiesFromJar = JSON.parse(JSON.stringify(cookieJar))._jar.cookies;

    const sessionID = parsedCookiesFromJar.find(cookie => cookie.key === 'JSESSIONID');
    const data = {
      token: `JSESSIONID=${sessionID.value}`
    };

    try {
      yield db.collection('users').doc(conv.user.storage.db).update(data);
      console.log('Updated token in database:', conv.user.storage.db);
    } catch (error) {
      return console.error('Error updating token in database:', error);
    }
  });
  return _updateTokenOnClose.apply(this, arguments);
}