"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.activeBets = exports.help = exports.results = exports.bye = exports.error = exports.balance = exports.clearData = exports.buyJoker = exports.buyLotto = exports.sms = exports.confirm = exports.otpfnr = exports.redeliver = exports.buy = exports.login = exports.welcome = void 0;

var _utils = require("./utils");

var _pluralize = _interopRequireDefault(require("pluralize"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Rule for pluralizing 'uker'
_pluralize.default.addPluralRule(/uke$/i, 'uker');

_pluralize.default.addPluralRule(/rekke$/i, 'rekker');

_pluralize.default.addPluralRule(/krone$/i, 'kroner');

const SOUNDS = {
  LOTTOINTRO: 'https://firebasestorage.googleapis.com/v0/b/bachelor-buypass-eu.appspot.com/o/soundEffects%2Flottointro.mp3?alt=media&amp;token=0557c2a7-6267-48db-a3e7-51dfc40a8c82',
  VIKINGINTRO: 'https://firebasestorage.googleapis.com/v0/b/bachelor-buypass-eu.appspot.com/o/soundEffects%2Fvikinglottointro.mp3?alt=media&amp;token=db34901b-7c61-46c1-a7ff-e48214fdd880'
};
const welcome = {
  welcomeToNT: _utils.ssml`
    <speak>
      <par>
        <media fadeOutDur="2.5s">
          <audio src="${SOUNDS.LOTTOINTRO}"/>
        </media>
        <media begin="6s">
          <speak>
            <prosody rate="high" pitch="-1st">
              <emphasis level="strong">
                Hei og velkommen til Norsk Tipping.
              </emphasis>
            </prosody>
          </speak>
        </media>
      </par>
    </speak>
  `,
  welcomeToNTWithName: name => _utils.ssml`
    <speak>
      <par>
        <media fadeOutDur="2.5s">
          <audio src="${SOUNDS.LOTTOINTRO}"/>
        </media>
        <media begin="6s">
          <speak>
            <prosody rate="high" pitch="-1st"><emphasis level="strong">
              Hei${name},<break time="250ms"/> velkommen tilbake til Norsk Tipping.
            </emphasis></prosody>
          </speak>
        </media>
      </par>
    </speak>
  `,
  welcomeNoSound: _utils.ssml`
    <speak>
      <prosody rate="high" pitch="-1st">
        <emphasis level="strong">
          Hei,<break time="250ms"/> velkommen til Norsk Tipping.
        </emphasis>
      </prosody>
    </speak>
  `,
  welcomeBackNoSound: _utils.ssml`
    <speak>
      <prosody rate="high" pitch="-1st"><emphasis level="strong">
        Hei,<break time="250ms"/> velkommen tilbake til Norsk Tipping.
      </emphasis></prosody>
    </speak>
`,
  help: _utils.ssml`
    <speak>
      <prosody rate="medium">Du kan velge mellom Lotto, 
      <break time="275ms"/>Vikinglotto, <break time="275ms"/>
      EuroJackpot <break time="275ms"/>eller Joker.</prosody>
      <break time="400ms"/> Hva har du lyst å spille?
    </speak>
  `,
  uncheckedBets: bets => {
    if (bets.length === 1) {
      return _utils.ssml`
      <speak>
        <p>
          <s>Du har ett spill du ikke har sjekket fra 
          den siste uka.</s>
          <s>Vil du høre resultat fra det nå?</s>
        </p>
      </speak>
      `;
    } else {
      return _utils.ssml`
        <speak>
          <p>
            <s>Du har ${bets.length} spill du ikke har sjekket fra 
            den siste uka.</s>
            <s>Vil du høre resultat fra noen av de nå?</s>
          </p>
        </speak>
      `;
    }
  }
};
exports.welcome = welcome;
const login = {
  loginNoScreen: _utils.ssml`
    <speak>
      For å kunne kjøpe et spill må du logge inn på Norsk Tipping. 
      <break time="400ms"/> 
      Dette kan du gjøre ved å snakke med Norsk Tipping i Google Home
      appen på din telefon.
    </speak>
  `,
  loginScreen: _utils.ssml`
    <speak>
      For å logge inn på Norsk Tipping trenger jeg ditt fødselsnummer.
    </speak>
  `,
  loginSurface: _utils.ssml`
    For å spille på Norsk Tipping må du først logge inn.
  `,
  revalidateNoScreen: _utils.ssml`
    <speak>
      Det er en stund siden sist du logget inn på Norsk Tipping. 
      <break time="400ms"/>For å logge inn på 
      nytt kan du snakke med Norsk Tipping i Google Home appen på 
      din telefon.           
    </speak>
  `,
  revalidateScreen: _utils.ssml`
    <speak>
      Det er en stund siden sist du logget inn på Norsk Tipping.
      <break time="400ms"/> For å logge inn på Norsk Tipping trenger
      jeg ditt fødselsnummer.
    </speak>
  `,
  revalidateSurface: _utils.ssml`
    Det er en stund siden sist du logget inn på Norsk Tipping. 
    For å spille på Norsk Tipping må du først logge inn.
  `,
  dontWantToConnectOrSaveId: _utils.ssml`
    <speak>
      <emphasis level="moderate">Det er greit</emphasis>
      <break time="300ms"/>bare snakk med meg igjen om du 
      ombestemmer deg senere!
    </speak>
  `,
  haveNotConnectedOnScreen: _utils.ssml`
    <speak>
      Jeg ser at du ikke har koblet til kontoen 
      dín,<break time="300ms"/> har du lyst å gjøre det nå?
    </speak>
  `,
  haveNotConnectedNotOnScreen: _utils.ssml`
    <speak>
      Jeg ser at du ikke har koblet til kontoen 
      dín,<break time="300ms"/> for å gjøre dette må du bruke 
      Google Assistent på din telefon.
    </speak>
  `,
  connected: name => _utils.ssml`
    <speak>
      <par>
        <media fadeOutDur="2.5s">
          <audio src="${SOUNDS.LOTTOINTRO}"/>
        </media>
        <media begin="6s">
          <speak>
            Flott<break time="200 ms"/>${name}. <break time="250 ms"/>
            Du er nå koblet til Norsk Tipping.
          </speak>
        </media>
      </par>
    </speak>
  `,
  connectedAskForConfirmationToSave: _utils.ssml`
  Tusen takk! Da er kontoen din tilkoblet. Vil du at jeg skal lagre 
  fødselsnummeret ditt, slik at du i fremtiden kan 
  logge inn med Google Home?
`
};
exports.login = login;
const buy = {
  promptPurchase: _utils.ssml`
    <speak>
      <p>
        <s>Hvis du lurer på hva du kan gjøre, spør om hjelp.</s>
        <s> Ellers bare si hva du vil spille.</s>
      </p>
    </speak>
  `,
  canIHelp: _utils.ssml`
    <speak>
      Kan jeg hjelpe deg med noe annet?
    </speak>
  `,
  buyMore: _utils.ssml`
    <speak>
	    Vil du spille noe mer?
    </speak>
  `,
  buySomethingElse: _utils.ssml`
    <speak>
    Den er grei. <break time="300ms"/>Har du lyst til å spille noe annet?
    </speak>
  `
};
exports.buy = buy;
const redeliver = {
  prompt: (gameName, couponPrice) => _utils.ssml`
    <speak>
      Vil du levere ${gameName} på nytt for 
      <say-as interpret-as="cardinal">${couponPrice}</say-as> kroner?
    </speak>
  `,
  more: _utils.ssml`
    <speak>
      <p>
        <s>Si fra hvis du vil ha flere resultater.</s>
        <s>Er det noe mer?</s>
      </p>
    </speak>
  `,
  delivered: (gameName, couponPrice) => _utils.ssml`
    <speak>
      Da har du levert ${gameName} neste uke for 
      <say-as interpret-as="cardinal">${couponPrice}</say-as> kroner.
    </speak>
  `,
  error: _utils.ssml`
    <speak>
      Det oppsto en feil ved levering av spill.
    </speak>
  `
};
exports.redeliver = redeliver;
const otpfnr = {
  receivingAndWritingOtp: _utils.ssml`
    <speak>
      <prosody rate="high">Du vil nå få en engangskode på SMS,
      </prosody><break time="300ms"/> skriv den inn her
    </speak>
  `,
  receivingAndSayingOtp: _utils.ssml`
    <speak>
      <prosody rate="high">Nå vil du få en engangskode på SMS,
      </prosody><break time="300ms"/> bare si tallene til meg 
      <break time="150ms"/>så skal jeg registrere dem for deg.
    </speak>
  `,
  savingFnr: _utils.ssml`
    <speak>
      <emphasis level="strong">Supert</emphasis><break time="300ms"/>, 
      da husker jeg det til neste gang.
    </speak>
  `,
  notSavingFnr: _utils.ssml`
    <speak>
      Den er grei.<break time="300ms"/> Da må du skrive inn 
      fødselsnummer neste gang du skal logge inn.
    </speak>
  `,
  invalidOTP: _utils.ssml`
    <speak>
      Ugyldig engangskode,<break time="300ms"/> prøv på nytt. 
    </speak>
  `,
  wrongOTP: _utils.ssml`
    <speak>
      Feil engangskode,<break time="300ms"/> prøv på nytt. 
    </speak>
  `,
  maxInvalidOTP: _utils.ssml`
    <speak>
      Du har lest inn feil engangskode for mange ganger.<break time="300ms" />
      Vennligst prøv på nytt senere.
    </speak>
  `,
  invalidFnr: _utils.ssml`
    <speak>
      Ugyldig fødselsnummer,<break time="300ms"/> prøv på nytt.
    </speak>
  `
};
exports.otpfnr = otpfnr;
const confirm = {
  confirmationEmail: name => _utils.ssml`
    <speak>
      <par>
        <media>
          <audio src="${SOUNDS.VIKINGINTRO}" fadeOutDur="3s"/>
        </media>
        <media begin="3.5s">
          <speak>
            Da er kjøpet gjennomført,<break time="300ms"/> jeg sender 
            deg en kvittering på e-post.<break time="450ms"/>
            <prosody volume="loud"> Lykke til<break time="200ms"/>${name}!</prosody>
          </speak>
        </media>
      </par>
    </speak>
  `,
  confirmationSMS: name => _utils.ssml`
    <speak>
      <par>
        <media>
          <audio src="${SOUNDS.VIKINGINTRO}" fadeOutDur="3s"/>
        </media>
        <media begin="3.5s">
          <speak>
            Da er kjøpet gjennomført,<break time="300ms"/> jeg sender 
            deg en kvittering på SMS.<break time="450ms"/>
            <prosody volume="loud"> Lykke til<break time="200ms"/>${name}!</prosody>
          </speak>
        </media>
      </par>
    </speak>
  `,
  deny: _utils.ssml`
    <speak>
      Helt i orden!<break time="350ms"/> Da er ikke noe spill 
      gjennomført.<break time="450ms"/>
    </speak>
  `,
  smsNotification: _utils.ssml`
    <speak>
      Du kan også få en påminnelse på SMS når denne trekningen er klar.
      Ønsker du det?
    </speak>
  `,
  smsNotificationYes: _utils.ssml`
    <speak>
      OK!<break time="350ms"/> Da vil jeg sende deg SMS med varsel om trekning. 
      Du kan be meg om å slutte å sende varsler hvis du ombestemmer deg.
    </speak>
  `,
  smsNotificationNo: _utils.ssml`
    <speak>
      OK!<break time="350ms"/> Da sender jeg ikke noen SMS. 
      Du kan be meg om å sende varsler om du ombestemmer deg.
    </speak>
  `
};
exports.confirm = confirm;
const sms = {
  startSending: _utils.ssml`
    <speak>
      Du vil nå begynne å få varsler på SMS.
    </speak>
  `,
  stopSending: _utils.ssml`
    <speak>
      Du vil ikke lenger få varsler på SMS.
    </speak>
  `,
  alreadySending: _utils.ssml`
    <speak>
      Du får allerede varsler på SMS.
    </speak>
  `,
  notSending: _utils.ssml`
    <speak>
      Du får ikke varsler på SMS.
    </speak>
  `
};
exports.sms = sms;
const buyLotto = {
  selectType: _utils.ssml`
    <speak>
      Vil du spille Lotto,<break time="250ms"/> Vikinglotto<break time="250ms"/>
      eller Eurojackpot?
    </speak>
  `,
  selectRowsEuro: _utils.ssml`
    <speak>
      Med <break time="10ms"/>Eurojackpot<break time="10ms"/> kan du 
      spille med mellom <break time="10ms"/>én<break time="10ms"/> 
      og <break time="10ms"/>ti rekker. <break time="300ms"/>
      Hvor mange vil du ha?
    </speak>
  `,
  selectRowsNotEuro: lottery_type => _utils.ssml`
    <speak>
      Med <break time="10ms"/>${lottery_type}<break time="10ms"/> 
      kan du spille med mellom <break time="10ms"/>to<break time="10ms"/> 
      og <break time="10ms"/>ti rekker. <break time="300ms"/>Hvor mange vil du ha?
    </speak>
  `,
  selectWeeks: _utils.ssml`
    <speak>
      <p>
        <s>
          Du kan velge å spille i mellom <break time="10ms"/>én <break time="50ms"/>og 
          <break time="10ms"/>26<break time="10ms"/> uker.
        </s>
        <s> 
          Hvor mange uker vil du ha?
        </s>
      </p>
    </speak>
  `,
  repeatChoice: (lottery_type, rows, weeks, couponPrice) => _utils.ssml`
    Flott! Du har valgt ${lottery_type} med ${rows} ${(0, _pluralize.default)('rekke', parseInt(rows))} for ${weeks} 
    ${(0, _pluralize.default)('uke', parseInt(weeks))}. Det koster ${couponPrice} ${(0, _pluralize.default)('krone', parseInt(couponPrice))}, 
    ønsker du å gjennomføre kjøpet?
  `,
  askOneMore: lottery_type => _utils.ssml`
    Du har valgt å kjøpe ${lottery_type} med en rekke, men du må kjøpe minst to.
    Vil du ha med to istedenfor?
  `
};
exports.buyLotto = buyLotto;
const buyJoker = {
  weekday: _utils.ssml`
    <speak>
      <emphasis level="moderate">Supert!</emphasis>
      <break time="400ms"/>Vil du spille på onsdag eller på lørdag?
    </speak>
  `,
  repeatChoice: (day, price) => _utils.ssml`
    Flott! Du har valgt Joker ${day}. Det blir ${price} ${(0, _pluralize.default)('krone', parseInt(price))}, 
    ønsker du å gjennomføre kjøpet?
  `
};
exports.buyJoker = buyJoker;
const clearData = {
  delete: _utils.ssml`
    <speak>
      <prosody rate="high">Det er greit.</prosody>
      <break time="350ms"/><prosody pitch="-1st">Da sletter 
      jeg all informasjon jeg har om deg.</prosody>
      <break time="450ms"/> Hvis du ønsker å bruke denne appen 
      senere må du registrere deg på nytt.
    </speak>
  `,
  deleted: _utils.ssml`
    <speak>
      Ok,<break time="250ms"/> jeg har slettet det jeg vet om deg.
    </speak>
  `
};
exports.clearData = clearData;
const balance = {
  success: amount => _utils.ssml`
    <speak>
      Du har <say-as interpret-as="cardinal">${amount.toString()}</say-as> 
      ${(0, _pluralize.default)('krone', parseInt(amount))} på spillekontoen din.
    </speak>
  `,
  saldo: balance => _utils.ssml`
    <speak>
      Du har <say-as interpret-as="cardinal">${balance}</say-as> ${(0, _pluralize.default)('krone', parseInt(balance))} 
      på spillekontoen din. 
    </speak>
  `
};
exports.balance = balance;
const error = {
  error: _utils.ssml`
    <speak>
      Oi! <break time="400ms"/>Det ser ut som om noe gikk galt,
      <break time="300ms"/> vennligst prøv igjen senere.
    </speak>
`,
  notLoggedIn: _utils.ssml`
    <speak>
      Du er ikke logget inn, <break time="300ms"/>
      vennligst logg inn og prøv på nytt.
    </speak>
  `,
  playerAccount: (balance, price) => _utils.ssml`
    <speak>
      Du har <say-as interpret-as="cardinal">${balance}</say-as> ${(0, _pluralize.default)('krone', parseInt(balance))} 
      på kontoen,<break time="300ms"/> men dette koster 
      <say-as interpret-as="cardinal">${price}</say-as> ${(0, _pluralize.default)('krone', parseInt(price))}.
      <break time="400ms"/> Du kan fylle på penger til spillekontoen din 
      på Norsk Tipping sin hjemmeside eller i Norsk Tipping appen.
    </speak>
  `,
  gameLimit: _utils.ssml`
    <speak>
      Du har nådd spillegrensen din.<break time="400ms"/> For mer informasjon 
      besøk hjemmesiden til Norsk Tipping eller Norsk Tipping appen.
    </speak>
  `,
  somethingWentWrong: _utils.ssml`
    <speak>
      Noe gikk galt.<break time="300ms"/> Ingen kjøp er gjennomført.
    </speak>
  `,
  listFallback: [_utils.ssml`
      <speak>
        Det fikk jeg ikke med meg.<break time="300ms"/> Kan du si det på nytt?
      </speak>
    `, _utils.ssml`
      <speak>
        Du kan for eksempel si<break time="100ms"/> "kjøp joker på lørdag",
        <break time="300ms"/> "kjøp fem rekker lotto denne uka" <break time="300ms"/> 
        eller "kjøp eurojackpot for to uker".
      </speak>
    `, _utils.ssml`
      <speak>
        Jeg hørte ikke hva du sa.<break time="300ms"/> Kan du si det en gang til?
      </speak>
    `],
  closeFallback: _utils.ssml`
    <speak>
      Beklager, jeg kan desverre ikke hjelpe deg.
      <break time="300ms"/> Ha en fin dag videre.
    </speak>
  `
};
exports.error = error;
const bye = {
  goodbye: name => _utils.ssml`
    <speak>Ha en fin dag${name}!</speak>
  `,
  acknowledgeAndBye: name => _utils.ssml`
    <speak>
      <p><s>Ok.</s><s>Ha en fin dag videre ${name}!</s></p>
    </speak>
  `
};
exports.bye = bye;
const results = {
  prize: (reason, amount, gameName) => _utils.ssml`
    <speak>
      <p>
        <s>På siste trekning med ${gameName} 
        fikk du ${reason}, og vant <say-as interpret-as="cardinal">${amount}</say-as> kroner! <break time="250ms"/>
        </s>
        <s>Gratulerer! </s>
      </p>
    </speak>`,
  noPrize: gameName => _utils.ssml`
   <speak>
      <p>
        <s>På siste trekning med ${gameName}<break time="150ms"/> ble det
        dessverre ingen premie. 
        </s>
        <s>Bedre lykke neste gang.</s>
      </p>
    </speak>
  `,
  notPlayedPastWeek: gameName => _utils.ssml`
    <speak>
      Du har ikke spilt ${gameName} den siste uken.
    </speak>
  `,
  listAllGames: gameNames => _utils.ssml`
    <speak>
      <p>
        <s>Den siste uken har du spilt ${gameNames}. </s>
        <s>Hvilken vil du høre om? </s>
      </p>
    </speak>
`
};
exports.results = results;
const help = {
  oneMoreRow: gameName => _utils.ssml`
    <speak>
      <p>
        <s>
          Det er ikke mulig å spille ${gameName} <break time="50ms"/> med én rekke.
        </s>
        <s>
          Vil du ha to rekker istedenfor?
        </s>
      </p>
    </speak>
  `,
  wantSmsNotification: _utils.ssml`
    <speak>
      <p>
        <s>
          Hvis du velger å motta SMS vil du få påminnelser for alle spill du kjøper med Google Home i fremtiden.
          Du kan når som helst be meg om å slutte med det.
        </s>
        <s>
          Ønsker du påminnelser?
        </s>
      </p>
    </speak>
  `,
  redeliver: (gamePrice, gameName) => _utils.ssml`
    <speak>
      <p>
        <s>
          Du kan levere ${gameName} fra forrige uke på nytt om du vil.
        </s>
        <s>
          Det blir isåfall <say-as interpret-as="cardinal">${gamePrice}</say-as> kroner.
        </s>
        <s>
          Vil du levere på nytt?
        </s>
      </p>
    </speak> 
  `,
  uncheckedBets: nrOfUnchecked => _utils.ssml`
    <speak>
      <p>
        <s>
          I løpet av de siste syv dagene har det vært ${nrOfUnchecked} trekninger du har kjøpt kuponger til.
        </s>
        <s>
          Vil du høre resultatet fra noen av de nå? 
        </s>
      </p>
    </speak>
  `,
  uncheckedBet: (formatWeekDay, gameName) => _utils.ssml`
    <speak>
      <p>
        <s>
          Du spilte ${gameName} ${formatWeekDay}, men du har ikke sjekket resultat fra denne enda.
        </s>
        <s>
          Vil du sjekke det nå? 
        </s>
      </p>
    </speak>
  `,
  saveData: _utils.ssml`
    <speak>
      <p>
        <s>
          Neste gang du skal logge inn trenger du bare å oppgi engangskode til Google Home.
        </s>
        <s>
          Isåfall må jeg lagre fødselsnummeret ditt.
        </s>
        <s>
          Er det greit?
        </s>
      </p>
    </speak>
  `,
  tokenInvalidFnr: _utils.ssml`
    <speak>
      <p>
        <s>
          Det har blitt sendt en SMS med engangskode til mobilnummeret som er registrert på Norsk Tipping-kontoen din.
        </s>
        <s>
          Gi meg koden, så skal jeg logge deg inn.
        </s>
      </p>
    </speak>
  `,
  tokenValid: _utils.ssml`
    <speak>
      <p>
        <s>
          Jeg kan kjøpe spill for deg<break time="70ms"/> og gi deg resultat fra spillene dine.
        </s>
        <s>
          Ellers kan jeg også sjekke saldo eller slette det jeg vet om deg.
        </s>
      </p>
    </speak>
  `,
  tokenInvalid: _utils.ssml`
    <speak>
      <p>
        <s>
          Jeg kan kjøpe spill for deg<break time="70ms"/> og gi deg resultat fra spillene dine.
        </s>
        <s>
          Ellers kan jeg også sjekke saldo eller slette det jeg vet om deg.
        </s>
        <s>
          Men først trenger jeg fødselsnummeret ditt for å logge deg inn.
        </s>
      </p>
    </speak>
  `
};
exports.help = help;
const activeBets = {
  noActiveBets: _utils.ssml`
    <speak>
      Du har ingen aktive spill.
    </speak>
  `,
  noActiveBetsSpecified: gameName => _utils.ssml`
    <speak>
      Du har ingen aktive spill i ${gameName}.
    </speak>
  `,
  listActiveBets: (noOfBets, gameNames) => _utils.ssml`
    <speak>
      <p>
        <s>Du har ${noOfBets} aktive spill. ${gameNames}.</s>
        <s>Hvilken vil du høre om?</s>
      </p>
    </speak>
  `,
  activeBetDetails: bet => {
    const [drawDate, drawTime] = bet.couponDetails.nextDrawDate.split(' ');
    return _utils.ssml`
      <speak>
        Neste trekning med ${bet.gameName} er 
        <say-as interpret-as="date" format="dm">${drawDate}</say-as> klokken
        <say-as interpret-as="time" format="hms24" detail='1'>${drawTime}</say-as>.
        Lykke til!
      </speak>
    `;
  }
};
exports.activeBets = activeBets;